==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QStackedLayout.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QStackedLayout (
  QStackedLayoutValue (..),
  QStackedLayoutConstPtr (..),
  QStackedLayoutPtr (..),
  QStackedLayoutConst,
  QStackedLayout,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithLayout,
  newWithParent,
  addWidget,
  count,
  currentIndex,
  currentWidget,
  insertWidget,
  setCurrentIndex,
  setCurrentWidget,
  setStackingMode,
  stackingMode,
  widget,
  currentChangedSignal,
  widgetRemovedSignal,
  QStackedLayoutStackingMode (..),
  ) where

import Graphics.UI.Qtah.Generated.Widgets.QStackedLayout
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP


castConst = toQStackedLayoutConst
cast = toQStackedLayout
downCastConst = downToQStackedLayoutConst
downCast = downToQStackedLayout

currentChangedSignal :: (QStackedLayoutPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
currentChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new fn'
    listenerInt_connectListener listener' object' "2currentChanged(int)"
  , QtahSignal.internalName = "QStackedLayout::currentChanged (ListenerInt)"
  }

widgetRemovedSignal :: (QStackedLayoutPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
widgetRemovedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new fn'
    listenerInt_connectListener listener' object' "2widgetRemoved(int)"
  , QtahSignal.internalName = "QStackedLayout::widgetRemoved (ListenerInt)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QStackedLayout.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QStackedLayout (
  QStackedLayoutValue (..),
  QStackedLayoutConstPtr (..),
  QStackedLayoutPtr (..),
  QStackedLayoutConst,
  QStackedLayout,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithLayout,
  newWithParent,
  addWidget,
  count,
  currentIndex,
  currentWidget,
  emitCurrentChanged,
  emitWidgetRemoved,
  insertWidget,
  setCurrentIndex,
  setCurrentWidget,
  setStackingMode,
  stackingMode,
  widget,
  currentChangedSignal,
  widgetRemovedSignal,
  QStackedLayoutStackingMode (..),
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import Graphics.UI.Qtah.Generated.Widgets.QStackedLayout
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQStackedLayoutConst
cast = toQStackedLayout
downCastConst = downToQStackedLayoutConst
downCast = downToQStackedLayout

currentChangedSignal :: (QStackedLayoutPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
currentChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new object' "2currentChanged(int)" fn'
    valid' <- listenerInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QStackedLayout::currentChanged (ListenerInt)"
  }

widgetRemovedSignal :: (QStackedLayoutPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.IO ())
widgetRemovedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerInt_new object' "2widgetRemoved(int)" fn'
    valid' <- listenerInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QStackedLayout::widgetRemoved (ListenerInt)"
  }
